<?php

namespace Moblyze\Plan\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Plan\Models\Floatpassenger;

class FloatpassengerPolicy
{

    /**
     * Determine if the given user can view the floatpassenger.
     *
     * @param UserPolicy $user
     * @param Floatpassenger $floatpassenger
     *
     * @return bool
     */
    public function view(UserPolicy $user, Floatpassenger $floatpassenger)
    {
        if ($user->canDo('plan.floatpassenger.view') && $user->isAdmin()) {
            return true;
        }

        return $floatpassenger->user_id == user_id() && $floatpassenger->user_type == user_type();
    }

    /**
     * Determine if the given user can create a floatpassenger.
     *
     * @param UserPolicy $user
     * @param Floatpassenger $floatpassenger
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('plan.floatpassenger.create');
    }

    /**
     * Determine if the given user can update the given floatpassenger.
     *
     * @param UserPolicy $user
     * @param Floatpassenger $floatpassenger
     *
     * @return bool
     */
    public function update(UserPolicy $user, Floatpassenger $floatpassenger)
    {
        if ($user->canDo('plan.floatpassenger.edit') && $user->isAdmin()) {
            return true;
        }

        return $floatpassenger->user_id == user_id() && $floatpassenger->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given floatpassenger.
     *
     * @param UserPolicy $user
     * @param Floatpassenger $floatpassenger
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Floatpassenger $floatpassenger)
    {
        return $floatpassenger->user_id == user_id() && $floatpassenger->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given floatpassenger.
     *
     * @param UserPolicy $user
     * @param Floatpassenger $floatpassenger
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Floatpassenger $floatpassenger)
    {
        if ($user->canDo('plan.floatpassenger.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given floatpassenger.
     *
     * @param UserPolicy $user
     * @param Floatpassenger $floatpassenger
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Floatpassenger $floatpassenger)
    {
        if ($user->canDo('plan.floatpassenger.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
