<?php

namespace Moblyze\Plan\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Plan\Models\Passenger;

class PassengerPolicy
{

    /**
     * Determine if the given user can view the passenger.
     *
     * @param UserPolicy $user
     * @param Passenger $passenger
     *
     * @return bool
     */
    public function view(UserPolicy $user, Passenger $passenger)
    {
        if ($user->canDo('plan.passenger.view') && $user->isAdmin()) {
            return true;
        }

        return $passenger->user_id == user_id() && $passenger->user_type == user_type();
    }

    /**
     * Determine if the given user can create a passenger.
     *
     * @param UserPolicy $user
     * @param Passenger $passenger
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('plan.passenger.create');
    }

    /**
     * Determine if the given user can update the given passenger.
     *
     * @param UserPolicy $user
     * @param Passenger $passenger
     *
     * @return bool
     */
    public function update(UserPolicy $user, Passenger $passenger)
    {
        if ($user->canDo('plan.passenger.edit') && $user->isAdmin()) {
            return true;
        }

        return $passenger->user_id == user_id() && $passenger->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given passenger.
     *
     * @param UserPolicy $user
     * @param Passenger $passenger
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Passenger $passenger)
    {
        return $passenger->user_id == user_id() && $passenger->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given passenger.
     *
     * @param UserPolicy $user
     * @param Passenger $passenger
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Passenger $passenger)
    {
        if ($user->canDo('plan.passenger.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given passenger.
     *
     * @param UserPolicy $user
     * @param Passenger $passenger
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Passenger $passenger)
    {
        if ($user->canDo('plan.passenger.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
