<?php

namespace Moblyze\Plan\Providers;

use Illuminate\Support\ServiceProvider;

class PlanServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'plan');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'plan');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerPlan();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerPlan()
    {
        $this->app->bind('plan', function($app) {
            return new Plan($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Plan', 'Lavalite\Plan\Facades\Plan');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('moblyze.plan', function ($app) {
            return $this->app->make('Moblyze\Plan\Plan');
        });

        // Bind Plan to repository
        $this->app->bind(
            'Moblyze\Plan\Interfaces\PlanRepositoryInterface',
            \Moblyze\Plan\Repositories\Eloquent\PlanRepository::class
        );        // Bind Location to repository
        $this->app->bind(
            'Moblyze\Plan\Interfaces\LocationRepositoryInterface',
            \Moblyze\Plan\Repositories\Eloquent\LocationRepository::class
        );        // Bind Crew to repository
        $this->app->bind(
            'Moblyze\Plan\Interfaces\CrewRepositoryInterface',
            \Moblyze\Plan\Repositories\Eloquent\CrewRepository::class
        );        // Bind Passenger to repository
        $this->app->bind(
            'Moblyze\Plan\Interfaces\PassengerRepositoryInterface',
            \Moblyze\Plan\Repositories\Eloquent\PassengerRepository::class
        );        // Bind Floatpassenger to repository
        $this->app->bind(
            'Moblyze\Plan\Interfaces\FloatpassengerRepositoryInterface',
            \Moblyze\Plan\Repositories\Eloquent\FloatpassengerRepository::class
        );        // Bind Users to repository
        $this->app->bind(
            'Moblyze\Plan\Interfaces\UsersRepositoryInterface',
            \Moblyze\Plan\Repositories\Eloquent\UsersRepository::class
        );        // Bind Manager to repository
        $this->app->bind(
            'Moblyze\Plan\Interfaces\ManagerRepositoryInterface',
            \Moblyze\Plan\Repositories\Eloquent\ManagerRepository::class
        );

        $this->app->register(\Moblyze\Plan\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Moblyze\Plan\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and plan's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'moblyze.plan'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakePlan::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['moblyze.plan'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('moblyze/plan.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/plan')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/plan')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
